from pathlib import Path
from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    app_name: str = "Shopping App"
    database_username: str
    database_password: str
    database_host: str
    database_name: str
    secret_key: str
    debug: bool = True

    @property
    def database_url(self) -> str:
        return f"mysql+pymysql://{self.database_username}:{self.database_password}@{self.database_host}/{self.database_name}"

    model_config = SettingsConfigDict(
        env_file=str(Path(__file__).resolve().parent.parent / ".env"),
        env_file_encoding="utf-8",
        case_sensitive=False,
    )


# Create a singleton instance to use in the app
settings = Settings()
